@@ -687,7 +687,7 @@ class Base(Controller):
     )
     def td(self):
         from ..ext.asana import add_todo, asana_list_todos, done_todo, fix_past_due
-        project = int(self.app.pargs.p or 0)
+        project = self.app.pargs.p or "Daily"
 
         if self.app.pargs.action=='add':
             add_todo(self.app.pargs.t, self.app.pargs.l, self.app.pargs.ws, project)
