@@ -72,7 +72,7 @@ def asana_get_todos(workspace_name,filtering):
     df = pd.DataFrame(tasks)
     return df
     
-def add_todo(task_text, expected_duration, workspace_id, project_name=0):
+def add_todo(task_text, expected_duration, workspace_id, project_name):
     tm = time.localtime()
     
     if expected_duration is None:
@@ -87,11 +87,12 @@ def add_todo(task_text, expected_duration, workspace_id, project_name=0):
     
     if workspace_id is None: workspace_id = me['workspaces'][0]['gid']
     projects = list(client.projects.get_projects_for_workspace(workspace_id))
-    if len(projects)!=1:
+    if project_name is None:
         project_name = 'Daily'
         project_id = [ w['gid'] for w in projects if w['name'] == project_name][0]
     else:
-        project_id = 0
+        # here project_name is id
+        project_id = projects[int(project_name)]['gid']
         
     # docs https://developers.asana.com/docs/create-a-task
         
@@ -99,11 +100,14 @@ def add_todo(task_text, expected_duration, workspace_id, project_name=0):
         "resource_subtype": "default_task",
         "assignee": me['gid'],
         "due_on": tar_date,
-        "projects": projects[project_id]['gid'],
+        "projects": project_id,
         # 'notes': 'Note: This is a test task created with the python-asana client.',
         # 'projects': [workspace_id]
     }
     
+    if project_name == '-1':
+        del data['projects']
+        
     print("posting", data)
     result = client.tasks.create_in_workspace(workspace_id, data)
 
