@@ -4,15 +4,14 @@ import humanize
 import time
 
 # construct a function that loads my openai API key from home and then calls it
-def load_config(api_key_file):
-    config = json.loads(open(api_key_file).read())
-    
+def load_config():
+    config_path = os.path.join(os.path.expanduser('~'), 'dt_config.json')
+    config = json.loads(open(config_path).read())   
     return config
 
 
 def show_config():
-    config_path = os.path.join(os.path.expanduser('~'), 'dt_config.json')
-    config = load_config(config_path)
+    config = load_config()
     
     for k in config.keys():
         # specific printing for snippets
@@ -25,8 +24,4 @@ def show_config():
                 print(f" {s[0]} ({delta}): \n  {s[2]}")   
         else:
             print(f"{k}: \n {config[k]}")
-        
-        
-def show_config_path():
-    config_path = os.path.join(os.path.expanduser('~'), 'dt_config.json')
-    print(config_path)
\ No newline at end of file
+
